@@ -22,12 +22,5 @@ __author__ = 'Robin Edwards'
 __email__ = 'robin.ge@gmail.com'
 __license__ = 'MIT'
 __package__ = 'neomodel'
-if (sys.version_info.major, sys.version_info.minor) >= (3, 8):
-    from importlib.metadata import version
-    neo_version = version("neomodel")
-else:
-    import pkg_resources
-    neo_version = pkg_resources.get_distribution('neomodel').version
-
-__version__ = neo_version
+__version__ = '4.0.10'
 
