@@ -1,3 +1,5 @@
+from operator import itemgetter
+
 from neomodel import StructuredNode, StringProperty, config
 from neomodel.core import db, remove_all_labels
 from neo4j.exceptions import ClientError
@@ -23,7 +25,8 @@ def test_drop_labels():
     indexes, meta = db.cypher_query("CALL db.indexes()")
 
     assert len(constraints) == 0
-    assert len(indexes) == 0
+    # Ignore the automatically created LOOKUP indexes
+    assert len([index for index in indexes if index[7] != []]) == 0
 
     # Returning all old constraints and indexes
     # Versions prior to 4.0 have a very different return format
@@ -37,6 +40,9 @@ def test_drop_labels():
             if not isinstance(index[0], int) and index[0].startswith('INDEX '):
                 db.cypher_query('CREATE ' + index[0])
             else:
+                # Ignore the automatically created LOOKUP indexes
+                if index[7] == []:
+                    continue
                 db.cypher_query('CREATE INDEX {0} FOR (n:{1}) ON (n.{2})'.format(index[1], index[7][0], index[8][0]))
         except ClientError:
             pass
